@@ -16,12 +16,6 @@ static GConfEnumStringPair panel_speed_map [] = {
         { PANEL_SPEED_FAST,   "panel-speed-fast" },
 };
 
-static GConfEnumStringPair panel_layer_map [] = {
-        { LAYER_BELOW, "panel-below-layer" },
-        { LAYER_NORMAL, "panel-normal-layer" },
-        { LAYER_ABOVE, "panel-above-layer" },
-};
-
 /*
  * Map between a gconf entry and a member of the
  * GlobalConfig structure.
@@ -35,50 +29,49 @@ panel_global_config_set_entry (GConfEntry *entry)
 	GConfValue *value;
 	gchar      *key;
 
+	g_return_if_fail (entry != NULL);
+
 	value = gconf_entry_get_value (entry);
+	key   = g_path_get_basename (gconf_entry_get_key (entry));
 
-	key = g_path_get_basename (gconf_entry_get_key (entry));
+	if (!value || !key)
+		return;
 
-	g_return_if_fail (key != NULL);
-#ifdef PANEL_GLOBAL_CONFIG_DEBUG
-	fprintf (stderr, "global config: handling %s\n", key);
-#endif
-
-	if (!strcmp (key, "tooltips-enabled"))
+	if (strcmp (key, "tooltips_enabled") == 0)
 		global_config.tooltips_enabled =
 				gconf_value_get_bool (value);
 
-	else if (!strcmp (key, "keep-menus-in-memory"))
+	else if (strcmp (key, "keep_menus_in_memory") == 0)
 		global_config.keep_menus_in_memory =
 				gconf_value_get_bool (value);
 
-	else if (!strcmp (key, "enable-animations"))
+	else if (strcmp (key, "enable_animations") == 0)
 		global_config.enable_animations =
 				gconf_value_get_bool (value);
 
-	else if (!strcmp (key, "panel-minimized-size"))
+	else if (strcmp (key, "panel_minimized_size") == 0)
 		global_config.minimized_size =
 				gconf_value_get_int (value);
 
-	else if (!strcmp (key, "panel-show-delay"))
+	else if (strcmp (key, "panel_show_delay") == 0)
 		global_config.show_delay =
 				gconf_value_get_int (value);
 
-	else if (!strcmp (key, "panel-animation-speed"))
+	else if (strcmp (key, "panel_animation_speed") == 0)
 		gconf_string_to_enum (
 			panel_speed_map,
 			gconf_value_get_string (value),
 			(gint *) &global_config.animation_speed);
 
-	else if (!strcmp (key, "panel-hide-delay"))
+	else if (strcmp (key, "panel_hide_delay") == 0)
 		global_config.hide_delay =
 				gconf_value_get_int (value);
 
-	else if (!strcmp (key, "enable-key-bindings"))
+	else if (strcmp (key, "enable_key_bindings") == 0)
 		global_config.keys_enabled =
 				gconf_value_get_bool (value);
 
-	else if (!strcmp (key, "menu-key")) { 
+	else if (strcmp (key, "menu_key") == 0) { 
 		if (global_config.menu_key.str)
 			g_free (global_config.menu_key.str);
 
@@ -87,7 +80,7 @@ panel_global_config_set_entry (GConfEntry *entry)
 
 		panel_parse_accelerator (&global_config.menu_key);
 
-	} else if (!strcmp (key, "run-key")) {
+	} else if (strcmp (key, "run_key") == 0) {
 		if (global_config.run_key.str)
 			g_free (global_config.run_key.str);
 
@@ -96,7 +89,7 @@ panel_global_config_set_entry (GConfEntry *entry)
 
 		panel_parse_accelerator (&global_config.run_key);
 
-	} else if (!strcmp (key, "screenshot-key")) {
+	} else if (strcmp (key, "screenshot_key") == 0) {
 		if (global_config.screenshot_key.str)
 			g_free (global_config.screenshot_key.str);
 
@@ -105,7 +98,7 @@ panel_global_config_set_entry (GConfEntry *entry)
 
 		panel_parse_accelerator (&global_config.screenshot_key);
 
-	} else if (!strcmp (key, "window-screenshot-key")) {
+	} else if (strcmp (key, "window_screenshot_key") == 0) {
 		if (global_config.window_screenshot_key.str)
 			g_free (global_config.window_screenshot_key.str);
 
@@ -114,25 +107,15 @@ panel_global_config_set_entry (GConfEntry *entry)
 
 		panel_parse_accelerator (&global_config.window_screenshot_key);
 
-	} else if (!strcmp (key, "auto-raise-panel"))
-		global_config.autoraise =
-			gconf_value_get_bool (value);
-
-	else if (!strcmp (key, "panel-window-layer"))
-		gconf_string_to_enum (
-			panel_layer_map,
-  			gconf_value_get_string (value),
-			(gint *) &global_config.layer);
-
-	else if (!strcmp (key, "drawer-autoclose"))
+	} else if (strcmp (key, "drawer_autoclose") == 0)
 		global_config.drawer_auto_close =
 			gconf_value_get_bool (value);
 
-	else if (!strcmp (key, "confirm-panel-remove"))
+	else if (strcmp (key, "confirm_panel_remove") == 0)
 		global_config.confirm_panel_remove =
 			gconf_value_get_bool (value);
 
-	else if (!strcmp (key, "highlight-launchers-on-mouseover"))
+	else if (strcmp (key, "highlight_launchers_on_mouseover") == 0)
 		global_config.highlight_when_over =
 			gconf_value_get_bool (value);
 
