@@ -33,9 +33,6 @@
 #include "panel.h"
 #include "multiscreen-stuff.h"
 
-/*
- * FIXME
- */
 #include "nothing.cP"
 
 static void config_apply (PerPanelConfig *ppc);
@@ -595,15 +592,14 @@ screen_set (GtkWidget *widget, gpointer data)
 }
 
 static GtkWidget *
-make_misc_widget (PerPanelConfig *ppc, gboolean avoiding)
+make_misc_widget (PerPanelConfig *ppc)
 {
 	GtkWidget *frame;
 	GtkWidget *box, *hbox;
 	GtkWidget *button, *label;
 	GtkObject *range;
 
-	if ( ! avoiding &&
-	    multiscreen_screens () <= 1)
+	if (multiscreen_screens () <= 1)
 		return NULL;
 
 	frame = gtk_frame_new (_("Miscellaneous"));
@@ -613,25 +609,23 @@ make_misc_widget (PerPanelConfig *ppc, gboolean avoiding)
 	gtk_container_set_border_width (GTK_CONTAINER (box), GNOME_PAD_SMALL);
 	gtk_container_add (GTK_CONTAINER (frame), box);
 	
-	if (multiscreen_screens () > 1) {
-		hbox = gtk_hbox_new (FALSE, 0);
-		gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
 
-		label = gtk_label_new (_("Current screen:"));
-		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	label = gtk_label_new (_("Current screen:"));
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-		range = gtk_adjustment_new (ppc->screen,
-					    0, multiscreen_screens () - 1,
-					    1, 1, 1);
-		ppc->screen_spin = button =
-			gtk_spin_button_new (GTK_ADJUSTMENT (range), 1, 0);
-		gtk_widget_set_size_request (GTK_WIDGET (button), 65, -1);
-		g_object_set_data (G_OBJECT (button), "PerPanelConfig", ppc);
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (button), ppc->screen);
-		g_signal_connect (G_OBJECT (button), "changed",
-				  G_CALLBACK (screen_set), NULL);
-		gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
-	}
+	range = gtk_adjustment_new (ppc->screen,
+				    0, multiscreen_screens () - 1,
+				    1, 1, 1);
+
+	ppc->screen_spin = button =
+		gtk_spin_button_new (GTK_ADJUSTMENT (range), 1, 0);
+	gtk_widget_set_size_request (GTK_WIDGET (button), 65, -1);
+	g_object_set_data (G_OBJECT (button), "PerPanelConfig", ppc);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (button), ppc->screen);
+	g_signal_connect (button, "changed", G_CALLBACK (screen_set), NULL);
+	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
 	return frame;
 }
@@ -664,20 +658,73 @@ border_set_align (GtkWidget *widget, gpointer data)
 	panel_config_register_changes (ppc);
 }
 
+static void
+make_position_widget_accessible (GtkWidget   *w,
+				 int          current,
+				 int          max,
+				 PanelOrient  orient)
+{
+	static const char *horiz_prefix[] = { "Left ", "Middle ", "Right " };
+	static const char *vert_prefix[] = { "Top ", "Middle ", "Bottom " };
+	char              *atk_name;
+	char              *str1 = "";
+	char              *str2 = "";
+
+	switch (orient) {
+	case PANEL_ORIENT_LEFT:
+		str2 = "Left Vertical";
+		break;
+	case PANEL_ORIENT_UP:
+		str2 = "Top Horizontal";
+		break;
+	case PANEL_ORIENT_RIGHT:
+		str2 = "Right Vertical";
+		break;
+	case PANEL_ORIENT_DOWN:
+		str2 = "Bottom Horizontal";
+		break;
+	}
+
+	if (max > 1) {
+		/* In this case, we have to skip the entry "Middle" */
+		if (max == 2 && current == 1)
+			current++;
+
+		switch (orient) {
+		case PANEL_ORIENT_LEFT:
+		case PANEL_ORIENT_RIGHT:
+			str1 = (char *) vert_prefix [current];
+			break;
+		case PANEL_ORIENT_UP:
+		case PANEL_ORIENT_DOWN:
+			str1 = (char *) horiz_prefix [current];
+			break;
+		}
+	}
+
+	atk_name = g_strconcat (str1, str2, NULL);
+
+	add_atk_name_desc (w, _(atk_name),
+			   _("Indicates the panel position and orientation on screen"));
+
+	g_free (atk_name);
+}
+
 static GtkWidget *
 make_position_widget (PerPanelConfig *ppc, int aligns)
 {
 	GtkWidget *pos_box;
 	GtkWidget *table;
 	GtkWidget *w = NULL;
+	GtkWidget *label;
 	int align;
 
 	pos_box = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_container_set_border_width (GTK_CONTAINER (pos_box),
 					GNOME_PAD_SMALL);
 
-	w = gtk_label_new (_("Panel Position"));
-	gtk_box_pack_start (GTK_BOX (pos_box), w, FALSE, FALSE, 0);
+	label = gtk_label_new (_("Panel Position"));
+	gtk_box_pack_start (GTK_BOX (pos_box), label, FALSE, FALSE, 0);
 
 	w = gtk_alignment_new (0.5, 0.5, 0, 0);	
 	gtk_box_pack_start (GTK_BOX (pos_box), w, FALSE, FALSE, 0);
@@ -685,6 +732,8 @@ make_position_widget (PerPanelConfig *ppc, int aligns)
 	table = gtk_table_new (2 + aligns, 2 + aligns, FALSE);
 	gtk_container_add (GTK_CONTAINER (w), table);
 
+	set_relation (table, GTK_LABEL (label), 1);
+
 	w = NULL;
 
 	/* LEFT */
@@ -701,12 +750,16 @@ make_position_widget (PerPanelConfig *ppc, int aligns)
 				  1 + align, 2 + align,
 				  GTK_FILL,
 				  GTK_EXPAND | GTK_FILL, 0, 0);
-		g_signal_connect (G_OBJECT (w), "toggled",
+
+		g_signal_connect (w, "toggled",
 				  G_CALLBACK (border_set_edge),
 				  GINT_TO_POINTER (BORDER_LEFT));
-		g_signal_connect (G_OBJECT (w), "toggled",
+		g_signal_connect (w, "toggled",
 				  G_CALLBACK (border_set_align),
 				  GINT_TO_POINTER (align));
+
+		make_position_widget_accessible (
+				w, align, aligns, PANEL_ORIENT_LEFT);
 	}
 	
 
@@ -722,12 +775,16 @@ make_position_widget (PerPanelConfig *ppc, int aligns)
 				  1 + align, 2 + align, 0, 1,
 				  GTK_EXPAND | GTK_FILL,
 				  0, 0, 0);
-		g_signal_connect (G_OBJECT (w), "toggled",
+
+		g_signal_connect (w, "toggled",
 				  G_CALLBACK (border_set_edge),
 				  GINT_TO_POINTER (BORDER_TOP));
-		g_signal_connect (G_OBJECT (w), "toggled",
+		g_signal_connect (w, "toggled",
 				  G_CALLBACK (border_set_align),
 				  GINT_TO_POINTER (align));
+
+		make_position_widget_accessible (
+				w, align, aligns, PANEL_ORIENT_UP);
 	}
 
 
@@ -744,12 +801,16 @@ make_position_widget (PerPanelConfig *ppc, int aligns)
 				  1 + align, 2 + align,
 				  GTK_FILL,
 				  GTK_FILL | GTK_EXPAND, 0, 0);
-		g_signal_connect (G_OBJECT (w), "toggled",
+
+		g_signal_connect (w, "toggled",
 				  G_CALLBACK (border_set_edge),
 				  GINT_TO_POINTER (BORDER_RIGHT));
-		g_signal_connect (G_OBJECT (w), "toggled",
+		g_signal_connect (w, "toggled",
 				  G_CALLBACK (border_set_align),
 				  GINT_TO_POINTER (align));
+
+		make_position_widget_accessible (
+				w, align, aligns, PANEL_ORIENT_RIGHT);
 	}
 
 
@@ -766,12 +827,16 @@ make_position_widget (PerPanelConfig *ppc, int aligns)
 				  1 + aligns, 2 + aligns,
 				  GTK_EXPAND | GTK_FILL,
 				  0, 0, 0);
-		g_signal_connect (G_OBJECT (w), "toggled",
+
+		g_signal_connect (w, "toggled",
 				  G_CALLBACK (border_set_edge),
 				  GINT_TO_POINTER (BORDER_BOTTOM));
-		g_signal_connect (G_OBJECT (w), "toggled",
+		g_signal_connect (w, "toggled",
 				  G_CALLBACK (border_set_align),
 				  GINT_TO_POINTER (align));
+
+		make_position_widget_accessible (
+				w, align, aligns, PANEL_ORIENT_DOWN);
 	}
 
 	update_position_toggles (ppc);
@@ -815,7 +880,7 @@ edge_notebook_page (PerPanelConfig *ppc)
 	w = make_hidebuttons_widget (ppc);
 	gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 
-	w = make_misc_widget (ppc, TRUE);
+	w = make_misc_widget (ppc);
 	if (w != NULL)
 		gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 	
@@ -850,7 +915,7 @@ aligned_notebook_page (PerPanelConfig *ppc)
 	w = make_hidebuttons_widget (ppc);
 	gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 
-	w = make_misc_widget (ppc, TRUE);
+	w = make_misc_widget (ppc);
 	if (w != NULL)
 		gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 	
@@ -957,6 +1022,8 @@ floating_notebook_page (PerPanelConfig *ppc)
 			  G_CALLBACK (floating_set_xy), &ppc->x);
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
+	set_relation (ppc->x_spin, GTK_LABEL (label), 1);
+
 	label = gtk_label_new (_("Y"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	
@@ -970,10 +1037,12 @@ floating_notebook_page (PerPanelConfig *ppc)
 			  G_CALLBACK (floating_set_xy), &ppc->y);
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
+	set_relation (ppc->y_spin, GTK_LABEL (label), 1);
+
 	w = make_hidebuttons_widget (ppc);
 	gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 
-	w = make_misc_widget (ppc, FALSE);
+	w = make_misc_widget (ppc);
 	if (w != NULL)
 		gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 	
@@ -1048,10 +1117,12 @@ sliding_notebook_page (PerPanelConfig *ppc)
 			  G_CALLBACK (sliding_set_offset), ppc);
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
+	set_relation (ppc->offset_spin, GTK_LABEL (l), 1);
+
 	w = make_hidebuttons_widget (ppc);
 	gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 	
-	w = make_misc_widget (ppc, TRUE);
+	w = make_misc_widget (ppc);
 	if (w != NULL)
 		gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 	
@@ -1072,18 +1143,6 @@ size_set_size (GtkWidget *widget, gpointer data)
 	panel_config_register_changes (ppc);
 }
 
-/* XXX: until this is fixed in GTK+ */
-static void
-activate_proper_item (GtkMenuShell *menu)
-{
-#ifdef FIXME
-	GtkWidget *active;
-	active = gtk_menu_shell_get_active (menu);
-	if (active != NULL)
-		gtk_menu_item_activate (GTK_MENU_ITEM (active));
-#endif
-}
-
 GtkWidget *
 make_size_widget (PerPanelConfig *ppc)
 {
@@ -1092,6 +1151,7 @@ make_size_widget (PerPanelConfig *ppc)
 	GtkWidget *menu;
 	GtkWidget *menuitem;
 	GtkWidget *w;
+	GtkWidget *label;
 	gchar *s;
 	int i;
 
@@ -1101,17 +1161,15 @@ make_size_widget (PerPanelConfig *ppc)
 	box = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 0);
 
+	label = gtk_label_new (_("Panel size:"));
 	gtk_box_pack_start (GTK_BOX (box),
-			    gtk_label_new (_("Panel size:")),
+			    label,
 			    FALSE, FALSE, 0);
 
 	
 	menu = gtk_menu_new ();
-	g_signal_connect (G_OBJECT (menu), "deactivate", 
-			  G_CALLBACK (activate_proper_item), 
-			  NULL);
 
-	menuitem = gtk_menu_item_new_with_label (_("XX Small Tiny (12 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("XX Small (12 pixels)"));
 	gtk_widget_show(menuitem);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_object_set_data (G_OBJECT (menuitem), "PerPanelConfig", ppc);
@@ -1172,6 +1230,8 @@ make_size_widget (PerPanelConfig *ppc)
 	
 	gtk_box_pack_start (GTK_BOX (box), ppc->size_menu,
 			    FALSE, FALSE, 0);
+
+	set_relation (ppc->size_menu, GTK_LABEL (label), 1);
 	
 	s = _("Note: The panel will size itself to the\n"
 	      "largest applet in the panel, and that\n"
@@ -1299,6 +1359,7 @@ background_page (PerPanelConfig *ppc)
 	GtkWidget *box, *f, *t;
 	GtkWidget *vbox, *noscale, *fit, *stretch;
 	GtkWidget *w, *m;
+	GtkWidget *label;
 
 	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_container_set_border_width(GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
@@ -1311,9 +1372,6 @@ background_page (PerPanelConfig *ppc)
 
 	/*background type option menu*/
 	m = gtk_menu_new ();
-	g_signal_connect (G_OBJECT (m), "deactivate", 
-			  G_CALLBACK (activate_proper_item), 
-			  NULL);
 	ppc->non = gtk_menu_item_new_with_label (_("Standard"));
 	g_object_set_data (G_OBJECT (ppc->non), "PerPanelConfig", ppc);
 	gtk_widget_show (ppc->non);
@@ -1331,6 +1389,7 @@ background_page (PerPanelConfig *ppc)
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (ppc->back_om), m);
 	gtk_box_pack_start (GTK_BOX (box), ppc->back_om, FALSE, FALSE, 0);
 
+	set_relation (ppc->back_om, GTK_LABEL (w), 1);
 
 	/*color frame*/
 	f = gtk_frame_new (_("Color"));
@@ -1345,7 +1404,8 @@ background_page (PerPanelConfig *ppc)
 	gtk_container_set_border_width(GTK_CONTAINER (box), GNOME_PAD_SMALL);
 	gtk_container_add (GTK_CONTAINER (f), box);
 
-	gtk_box_pack_start (GTK_BOX (box), gtk_label_new (_("Color to use:")),
+	label = gtk_label_new (_("Color to use:"));
+	gtk_box_pack_start (GTK_BOX (box), label,
 			    FALSE, FALSE, GNOME_PAD_SMALL);
 
 	ppc->backsel = gnome_color_picker_new();
@@ -1357,6 +1417,7 @@ background_page (PerPanelConfig *ppc)
 				   ppc->back_color.green,
 				   ppc->back_color.blue,
 				   65535);
+	set_relation (ppc->backsel, GTK_LABEL (label), 1);
 
 	gtk_box_pack_start (GTK_BOX (box), ppc->backsel, FALSE, FALSE, 0);
 
@@ -1530,7 +1591,7 @@ window_response (GtkWidget *w, int response, gpointer data)
 		tab = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
 
 		if (tab == 1)
-			panel_show_help ("panelproperties", "PANELBACKTAB");
+			panel_show_help ("wgospanel.xml", "gospanel-28");
 		else
 			panel_show_help (help_path, help_linkid);
 	} else {
@@ -1609,8 +1670,8 @@ panel_config (GtkWidget *panel)
 
 	if(EDGE_IS_WIDGET(panel)) {
 		/* edge notebook page */
-		help_path = "panelproperties";
-		help_linkid = "EDGETAB";
+		help_path = "wgospanel.xml";
+		help_linkid = "gospanel-28";
 		page = edge_notebook_page(ppc);
 		ppc->type_tab = gtk_event_box_new();
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
@@ -1620,8 +1681,8 @@ panel_config (GtkWidget *panel)
 					 ppc->type_tab_label);
 	} else if(ALIGNED_IS_WIDGET(panel)) {
 		/* aligned notebook page */
-		help_path = "panelproperties";
-		help_linkid = "EDGETAB";
+		help_path = "wgospanel.xml";
+		help_linkid = "gospanel-28";
 		page = aligned_notebook_page(ppc);
 		ppc->type_tab = gtk_event_box_new();
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
@@ -1631,8 +1692,8 @@ panel_config (GtkWidget *panel)
 					 ppc->type_tab_label);
 	} else if(SLIDING_IS_WIDGET(panel)) {
 		/* sliding notebook page */
-		help_path = "panelproperties";
-		help_linkid = "EDGETAB";
+		help_path = "wgospanel.xml";
+		help_linkid = "gospanel-28";
 		page = sliding_notebook_page(ppc);
 		ppc->type_tab = gtk_event_box_new();
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
@@ -1642,8 +1703,8 @@ panel_config (GtkWidget *panel)
 					 ppc->type_tab_label);
 	} else if(FLOATING_IS_WIDGET(panel)) {
 		/* floating notebook page */
-		help_path = "panelproperties";
-		help_linkid = "EDGETAB";
+		help_path = "wgospanel.xml";
+		help_linkid = "gospanel-28";
 		page = floating_notebook_page(ppc);
 		ppc->type_tab = gtk_event_box_new();
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
@@ -1657,8 +1718,8 @@ panel_config (GtkWidget *panel)
 		AppletInfo *info =
 			g_object_get_data (G_OBJECT (applet), "applet_info");
 		add_drawer_properties_page(ppc, GTK_NOTEBOOK (prop_nbook), info->data);
-		help_path = "drawers";
-		help_linkid = NULL;
+		help_path = "wgospanel.xml";
+		help_linkid = "gospanel-550";
 		/* we can't change to/from drawers anyhow */
 		ppc->type_tab = NULL;
  	}
